## Pull Requests are Disabled

Bugsink is proprietary software that is not open to contributions through the PR mechanism.

I would love to disable the PR tab entirely, but [Github doesn't allow me](https://github.com/orgs/community/discussions/8907)

_However_, help in other ways is certainly welcome:

* Open [issues](https://www.github.com/bugsink/bugsink/issues) for bugs, feature requests, or other feedback
* Reaching out with your feeback
* Spreading the word about Bugsink
